require 'currency_wiz/version'
require 'currency_wiz/config'

# require_relative '../lib/currency_wiz/version.rb'
# require_relative '../lib/currency_wiz/config.rb'

require 'httparty'

module CurrencyWiz
  extend self

  CURRENCY_CODES = {
    "AED"=> "United Arab Emirates Dirham",
    "AFN"=> "Afghan Afghani Afghanistan",
    "ALL"=> "Albanian Lek Albania",
    "AMD"=> "Armenian Dram Armenia",
    "ANG"=> "Netherlands Antillean Guilder",
    "AOA"=> "Angolan Kwanza Angola",
    "ARS"=> "Argentine Peso Argentina",
    "AUD"=> "Australian Dollar Australia",
    "AWG"=> "Aruban Florin Aruba",
    "AZN"=> "Azerbaijani Manat Azerbaijan",
    "BAM"=> "Bosnia-Herzegovina Convertible Mark",
    "BBD"=> "Barbadian Dollar Barbados",
    "BDT"=> "Bangladeshi Taka Bangladesh",
    "BGN"=> "Bulgarian Lev Bulgaria",
    "BHD"=> "Bahraini Dinar Bahrain",
    "BIF"=> "Burundian Franc Burundi",
    "BMD"=> "Bermudan Dollar Bermuda",
    "BND"=> "Brunei Dollar",
    "BOB"=> "Bolivian Boliviano",
    "BRL"=> "Brazilian Real",
    "BSD"=> "Bahamian Dollar Bahama",
    "BTC"=> "Bitcoin",
    "BTN"=> "Bhutanese Ngultrum",
    "BWP"=> "Botswanan Pula",
    "BYR"=> "Belarusian Ruble",
    "BZD"=> "Belize Dollar",
    "CAD"=> "Canadian Dollar Canada",
    "CDF"=> "Congolese Franc",
    "CHF"=> "Swiss Franc Switzerland",
    "CLF"=> "Chilean Unit of Account (UF)",
    "CLP"=> "Chilean Peso",
    "CNY"=> "Chinese Yuan China",
    "COP"=> "Colombian Peso",
    "CRC"=> "Costa Rican Colon",
    "CUP"=> "Cuban Peso",
    "CVE"=> "Cape Verdean Escudo",
    "CZK"=> "Czech Republic Koruna",
    "DJF"=> "Djiboutian Franc",
    "DKK"=> "Danish Krone Denmark",
    "DOP"=> "Dominican Peso Dominican Republic",
    "DZD"=> "Algerian Dinar",
    "EEK"=> "Estonian Kroon",
    "EGP"=> "Egyptian Pound",
    "ETB"=> "Ethiopian Birr",
    "EUR"=> "Euro",
    "FJD"=> "Fijian Dollar",
    "FKP"=> "Falkland Islands Pound",
    "GBP"=> "British Pound Sterling England",
    "GEL"=> "Georgian Lari",
    "GHS"=> "Ghanaian Cedi",
    "GIP"=> "Gibraltar Pound",
    "GMD"=> "Gambian Dalasi",
    "GNF"=> "Guinean Franc",
    "GTQ"=> "Guatemalan Quetzal",
    "GYD"=> "Guyanaese Dollar",
    "HKD"=> "Hong Kong Dollar",
    "HNL"=> "Honduran Lempira Honduras",
    "HRK"=> "Croatian Kuna",
    "HTG"=> "Haitian Gourde",
    "HUF"=> "Hungarian Forint",
    "IDR"=> "Indonesian Rupiah",
    "ILS"=> "Israeli New Sheqel",
    "INR"=> "Indian Rupee",
    "IQD"=> "Iraqi Dinar",
    "IRR"=> "Iranian Rial",
    "ISK"=> "Icelandic Krona",
    "JEP"=> "Jersey Pound",
    "JMD"=> "Jamaican Dollar",
    "JOD"=> "Jordanian Dinar",
    "JPY"=> "Japanese Yen",
    "KES"=> "Kenyan Shilling",
    "KGS"=> "Kyrgystani Som",
    "KHR"=> "Cambodian Riel",
    "KMF"=> "Comorian Franc",
    "KPW"=> "North Korean Won",
    "KRW"=> "South Korean Won",
    "KWD"=> "Kuwaiti Dinar",
    "KYD"=> "Cayman Islands Dollar",
    "KZT"=> "Kazakhstani Tenge",
    "LAK"=> "Laotian Kip",
    "LBP"=> "Lebanese Pound Lebanon",
    "LKR"=> "Sri Lankan Rupee",
    "LRD"=> "Liberian Dollar",
    "LSL"=> "Lesotho Loti",
    "LTL"=> "Lithuanian Litas",
    "LVL"=> "Latvian Lats",
    "LYD"=> "Libyan Dinar",
    "MAD"=> "Moroccan Dirham Morocco",
    "MDL"=> "Moldovan Leu",
    "MGA"=> "Malagasy Ariary",
    "MKD"=> "Macedonian Denar",
    "MMK"=> "Myanma Kyat",
    "MNT"=> "Mongolian Tugrik",
    "MOP"=> "Macanese Pataca",
    "MRO"=> "Mauritanian Ouguiya",
    "MTL"=> "Maltese Lira",
    "MUR"=> "Mauritian Rupee",
    "MVR"=> "Maldivian Rufiyaa",
    "MWK"=> "Malawian Kwacha",
    "MXN"=> "Mexican Peso Mexico",
    "MYR"=> "Malaysian Ringgit",
    "MZN"=> "Mozambican Metical",
    "NAD"=> "Namibian Dollar",
    "NGN"=> "Nigerian Naira",
    "NIO"=> "Nicaraguan Cordoba",
    "NOK"=> "Norwegian Krone Norway",
    "NPR"=> "Nepalese Rupee",
    "NZD"=> "New Zealand Dollar",
    "OMR"=> "Omani Rial",
    "PAB"=> "Panamanian Balboa",
    "PEN"=> "Peruvian Nuevo Sol",
    "PGK"=> "Papua New Guinean Kina",
    "PHP"=> "Philippine Peso",
    "PKR"=> "Pakistani Rupee",
    "PLN"=> "Polish Zloty Poland",
    "PYG"=> "Paraguayan Guarani",
    "QAR"=> "Qatari Rial",
    "RON"=> "Romanian Leu",
    "RSD"=> "Serbian Dinar",
    "RUB"=> "Russian Ruble",
    "RWF"=> "Rwandan Franc",
    "SAR"=> "Saudi Riyal Saudi Arabia",
    "SBD"=> "Solomon Islands Dollar",
    "SCR"=> "Seychellois Rupee",
    "SDG"=> "Sudanese Pound",
    "SEK"=> "Swedish Krona Swedan",
    "SGD"=> "Singapore Dollar",
    "SHP"=> "Saint Helena Pound",
    "SLL"=> "Sierra Leonean Leone",
    "SOS"=> "Somali Shilling Somalia",
    "SRD"=> "Surinamese Dollar",
    "STD"=> "Sao Tome and Principe Dobra",
    "SVC"=> "Salvadoran Colon El Salvador",
    "SYP"=> "Syrian Pound",
    "SZL"=> "Swazi Lilangeni Swaziland",
    "THB"=> "Thai Baht Thailand",
    "TJS"=> "Tajikistani Somoni",
    "TMT"=> "Turkmenistani Manat",
    "TND"=> "Tunisian Dinar",
    "TOP"=> "Tongan Paanga",
    "TRY"=> "Turkish Lira Turkey",
    "TTD"=> "Trinidad and Tobago Dollar",
    "TWD"=> "New Taiwan Dollar",
    "TZS"=> "Tanzanian Shilling",
    "UAH"=> "Ukrainian Hryvnia",
    "UGX"=> "Ugandan Shilling",
    "USD"=> "United States Dollar",
    "UYU"=> "Uruguayan Peso",
    "UZS"=> "Uzbekistan Som",
    "VEF"=> "Venezuelan Bolivar Fuerte",
    "VND"=> "Vietnamese Dong Vietnam",
    "VUV"=> "Vanuatu Vatu",
    "WST"=> "Samoan Tala",
    "XAF"=> "CFA Franc BEAC",
    "XAG"=> "Silver (troy ounce)",
    "XAU"=> "Gold (troy ounce)",
    "XCD"=> "East Caribbean Dollar",
    "XDR"=> "Special Drawing Rights",
    "XOF"=> "CFA Franc BCEAO",
    "XPF"=> "CFP Franc",
    "YER"=> "Yemeni Rial",
    "ZAR"=> "South African Rand",
    "ZMK"=> "Zambian Kwacha (pre-2013)",
    "ZMW"=> "Zambian Kwacha",
    "ZWL"=> "Zimbabwean Dollar"
	}

	def get_code(country)
		CURRENCY_CODES.each do |k, v|
			if v.downcase.include?(country.downcase)
				return k
			end
		end
		return "Invalid country name"
	end

  def exchange_rate(country_code)
    response = HTTParty.get("http://openexchangerates.org/api/latest.json?app_id=#{CurrencyWiz::Config::API_KEY}")

    response["rates"].each do |k, v|
      if k == country_code
        return v
      end
    end

    return nil

  end


end

